@@ -80,57 +80,64 @@ static void start_sequencer(JammoMentor* mentor, const gchar* speech, gboolean i
 	singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
 }
 
-static void say_start_after_prelude(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer sequencer){
-	if (interrupted){
-		start_sequencer(NULL, NULL, interrupted, sequencer);
-		return;
-	}
-
-	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "songstartC.spx", start_sequencer, sequencer);
-}
-
-
-static void say_name_of_song(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer sequencer){
-	if (interrupted){
-		start_sequencer(NULL, NULL, interrupted, sequencer);
-		return;
-	}
-
-	jammo_song* song = chum_get_current_song();
-	gchar *filepath1;
-	filepath1 =  g_strdup_printf("%s/name%s.spx", song->fullpath, chum_get_selected_language());
-	//printf("pass to mentor: '%s' \n",filepath1);
-
-	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), filepath1, say_start_after_prelude, sequencer);
-	g_free(filepath1);
-}
 
 static void song_view_showed(ClutterTimeline* t, gpointer sequencer){
 	printf("song_view_showed\n");
+	jammo_song* song = chum_get_current_song();
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "");
 
+	gboolean vocal_on_language=TRUE;
+
+	gchar* audio_filename;
+	audio_filename = g_strdup_printf("%s/vocal%s.ogg",song->fullpath,chum_get_selected_language());
+	int fd = open(audio_filename,O_RDONLY);
+	if (fd == -1) //File not found => no vocal_track for this language
+		vocal_on_language=FALSE;
+	g_free(audio_filename);
+	close(fd);
+
+	int fd_name; //Checking if there are nameXX.spx
+	int fd_intro; //Checking if there are introXX.spx
+	gchar* mentor_tells="";
+
 	//If song doesn't have "name_XX.spx" look for "intro_XX.spx"
-	//And then it replaces all other mentor's speaches on this step.
-	jammo_song* song = chum_get_current_song();
 	gchar *filepath1;
 	filepath1 =  g_strdup_printf("%s/name%s.spx", song->fullpath, chum_get_selected_language());
-	int fd;
-	fd = open(filepath1,O_RDONLY);
-	if (fd == -1) //File not found
-		{
-		close(fd);
-		g_free(filepath1);
+	printf("song.c: looking for name_XX:'%s'\n",filepath1);
+	fd_name = open(filepath1,O_RDONLY);
+	g_free(filepath1);
+
+	if (fd_name == -1) {  //nameXX File not found
 		filepath1 =  g_strdup_printf("%s/intro%s.spx", song->fullpath, chum_get_selected_language());
-		fd = open(filepath1,O_RDONLY);
-		if (fd == -1) //File not found
-			{ //No name_XX nor intro_XX, just start sequencer.
-			start_sequencer(NULL,NULL,FALSE,sequencer);
-			}
-		else  //say intro_XX and after that start sequencer
-			jammo_mentor_speak_with_callback(jammo_mentor_get_default(), filepath1, start_sequencer, sequencer);
+		printf("song.c: looking for intro_XX:'%s'\n",filepath1);
+		fd_intro = open(filepath1,O_RDONLY);
+		if (fd_intro == -1) { //intro_XX File not found
+			//No name_XX nor intro_XX, say: "start after prelude"
+			printf("not founded name_XX or intro_XX\n");
+			mentor_tells = g_strdup_printf("songstartC.spx %s",
+                vocal_on_language?"":"no_vocal_on_this_song.spx"
+                );
 		}
-	else //say "you have selected" + name_XX + "start after prelude" and then start sequencer
-		jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "songstartA.spx", say_name_of_song, sequencer);
+		else  { //say only intro_XX
+			printf("intro_XX founded (but not name_XX)\n");
+			mentor_tells = g_strdup_printf("%s", filepath1);
+		}
+		g_free(filepath1);
+		close(fd_intro);
+	}
+	else //This is 'normal'-case!
+	  {   //say "you have selected" + name_XX (+ no_vocal_for_this_language) +"start after prelude"
+		mentor_tells = g_strdup_printf("songstartA.spx %s/name%s.spx %s songstartC.spx",
+             song->fullpath, chum_get_selected_language(),
+             vocal_on_language?"":"no_vocal_on_this_song.spx"
+             );
+		}
+
+	close(fd_name);
+
+	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), mentor_tells, start_sequencer, sequencer);
+	g_free(mentor_tells);
+
 }
 
 static void start_sequencer_after_animation(ClutterTimeline* t, gpointer sequencer){
