@@ -98,7 +98,8 @@ void midieditor_zoom_clicked  (TangleButton *tanglebutton, gpointer user_data)
 	if (tangle_button_get_selected(tanglebutton)) { //Zoom Out;
 		printf("zoom out\n");
 		//if scrolled very bottom and zoomed out, track is ouside of view
-		g_object_set(jammo_get_actor_by_id( "midieditor-track-scroller"), "scrolling-offset-x", 0.0, "scrolling-offset-y", 0.0, NULL);
+		ClutterAction* scroll_action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("midieditor-container-for-track"),TANGLE_TYPE_SCROLL_ACTION);
+		tangle_scroll_action_set_offsets(TANGLE_SCROLL_ACTION(scroll_action), 0.0,0.0);
 
 		width = 700.0;
 		height = 400.0;
@@ -247,7 +248,6 @@ static void start_midi_editor(void) {
 
 	//CHUM (graphical)
 	ClutterActor* container_for_piano_roll;
-	ClutterActor* scrolling_actor_for_piano_roll;
 	ClutterActor* texture_for_cursor;
 
 	ClutterActor* container_for_track =  jammo_get_actor_by_id("midieditor-container-for-track");
@@ -272,7 +272,7 @@ static void start_midi_editor(void) {
 	//We make two different size piano_roll (zoomed-in and zoomed-out)
 
 	//We need container for piano roll because we want change content of piano_roll (e.g. when zooming)
-	container_for_piano_roll = tangle_widget_new();
+	container_for_piano_roll = jammo_get_actor_by_id("midieditor-container-for-pianokeys");
 
 	static_piano_roll_in = create_piano_roll(height_of_grid_slot,highest_note,lowest_note,FALSE);
 	static_piano_roll_out = create_piano_roll(400.0/(highest_note-lowest_note+1),highest_note,lowest_note,FALSE);
@@ -281,14 +281,10 @@ static void start_midi_editor(void) {
 	clutter_actor_hide(static_piano_roll_out); //Hide zoomed-out version
 
 
-	scrolling_actor_for_piano_roll = tangle_scrolling_actor_new(container_for_piano_roll);
-	clutter_actor_set_position(scrolling_actor_for_piano_roll, 0.0, 0.0);
-	clutter_actor_set_size(scrolling_actor_for_piano_roll, 100.0, 400.0);
-	tangle_widget_add(TANGLE_WIDGET(view), scrolling_actor_for_piano_roll, NULL);
-
 	//Bind piano_roll and grid together.
-	tangle_binding_new(G_OBJECT(scrolling_actor_for_piano_roll), "scrolling-offset-y",
-   G_OBJECT(jammo_get_actor_by_id( "midieditor-track-scroller")), "scrolling-offset-y");
+	ClutterAction* action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("midieditor-container-for-track"),TANGLE_TYPE_SCROLL_ACTION);
+	ClutterAction* action_piano = tangle_actor_get_action_by_type(jammo_get_actor_by_id("midieditor-container-for-pianokeys"),TANGLE_TYPE_SCROLL_ACTION);
+	tangle_binding_new(G_OBJECT(action_piano), "offset-y", G_OBJECT(action), "offset-y");
 
 
 	//Cursor
