@@ -33,33 +33,14 @@ View contains three part:
 #include "sequencer_track_view.h"
 #include "startmenu.h"
 
-//Copy pasted from jammo-backing-track.c
-static gchar* str_replace(gchar* string, gsize position, gsize length, const gchar* replacement, gchar** replacement_end_return) {
-	gsize string_length;
-	gsize replacement_length;
-	gchar* s;
-	
-	string_length = strlen(string);
-	replacement_length = strlen(replacement);
-	s = (gchar*)g_malloc(string_length - length + replacement_length + 1);
-	g_memmove(s, string, position);
-	g_memmove(s + position, replacement, replacement_length);
-	g_memmove(s + position + replacement_length, string + position + length, string_length - position - length + 1);
-
-	if (replacement_end_return) {
-		*replacement_end_return = s + position + replacement_length;
-	}
-
-	g_free(string);
-
-	return s;
-}
 
 /*
+Sequencer and sequencer-track-view-area are defined in json.
+
 When sequencer starts: it calls load_state_from_file(load_only_backingtrack=TRUE)
  It starts loading backing-track.
  When backing_track is loaded (on_duration_notify)
-  It creates sequencer and sequencer-track-view-area.
+  Tell sequencer_track_view_area that now duration is known (used e.g. with cursor)
   Then load_state_from_file(load_only_backingtrack=FALSE) loads another tracks.
 */
 
@@ -67,10 +48,53 @@ When sequencer starts: it calls load_state_from_file(load_only_backingtrack=TRUE
 //All new tracks are added to this
 //If metronome is enabled it is added to this
 JammoSequencer* static_sequencer;
-
+JammoMetronomeTrack* static_metronome_track;
 
 static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer track);
 
+/*
+Each jammo-sample-button has loop-id.
+First digit tells type of loop.
+
+Will return NULL, if anything goeas wrong.
+
+This function might be usefull for networking play (make it non-static)
+*/
+
+static ClutterActor* sequencer_give_sample_button_for_this_id(guint id){
+	guint id_; //Id without first digit
+	gchar* type;
+	if (id>=100 && id <200){
+		type="rhytmical";
+		id_=id-100;
+	} else if (id>=200 && id <300) {
+		type="melodical";
+		id_=id-200;
+	} else if (id>=300 && id <400) {
+		type="harmonical";
+		id_=id-300;
+	}	else if (id>=400 && id <500) {
+		type="effect";
+		id_=id-400;
+	} else {
+		return NULL;
+	}
+
+	gchar* name;
+	name = g_strdup_printf("%s_sample_%d", type,id_);
+
+	JammoSampleButton* sb = JAMMO_SAMPLE_BUTTON(jammo_get_actor_by_id(name)); //clone this!
+	g_free(name);
+	//It is unique, we can't return it.  We make clone of it.
+	ClutterActor* sample_button = NULL;
+	
+	if (sb) {
+		sample_button = jammo_sample_button_new_from_files(jammo_sample_button_get_image_filename(sb),jammo_sample_button_get_sample_filename(sb));
+		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button),jammo_sample_button_get_loop_id(sb));
+	}
+	return sample_button;  //If sb was NULL, we will return sample_button=NULL.
+}
+
 static void load_state_from_file(gchar* filename, gboolean load_only_backingtrack) {
 
 JsonParser *parser;
@@ -176,10 +200,18 @@ if (load_only_backingtrack){
 			//boolean. We need this to construct track_view
 			gboolean muted=FALSE; //default
 			sub_node = json_object_get_member (sub_object, "muted");
-				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					muted = json_node_get_boolean (sub_node);
-					printf(" muted: '%d'\n",muted);
-				}
+			if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+				muted = json_node_get_boolean (sub_node);
+				printf(" muted: '%d'\n",muted);
+			}
+
+			// double/float
+			gfloat volume=1.0; //default volume is 100%
+			sub_node = json_object_get_member (sub_object, "volume");
+			if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+				volume = (gfloat) json_node_get_double (sub_node);
+				printf("volume: '%f'\n",volume);
+			}
 
 			if(load_only_backingtrack) {
 			//BACKING-TRACK
@@ -195,36 +227,8 @@ if (load_only_backingtrack){
 
 						track = JAMMO_TRACK(jammo_backing_track_new(backing_track_filename));
 						// Create other tracks after the duration of the backing track is known.
-						JammoSample* sample;
-						printf("pitch '%s', tempo '%d'\n",pitch,tempo);
-
-						//This code is copy-pasted from jammo-backing-track.c:287
-						gchar* s;
-						gchar* filename_for_sample = s = g_strdup(backing_track_filename);
-						gchar* tempo_string;
-						while ((s = strchr(s, '$'))) {
-							switch (s[1]) {
-								case '$':
-									filename_for_sample = str_replace(filename_for_sample, s - filename_for_sample, 2, "$", &s);
-									break;
-								case 't':
-									tempo_string = g_strdup_printf("%u", tempo);
-									filename_for_sample = str_replace(filename_for_sample, s - filename_for_sample, 2, tempo_string, &s);
-									g_free(tempo_string);
-									break;
-								case 'p':
-									filename_for_sample = str_replace(filename_for_sample, s - filename_for_sample, 2, pitch, &s);
-									break;
-								default:
-									g_warning("Unexpected parameter in the backing track filename: '$%c', skipped.", s[1]);
-									s += 2;
-									break;
-							}
-						}
-						sample = jammo_sample_new_from_file(filename_for_sample);
-						g_free(filename_for_sample);
-						g_signal_connect(sample, "notify::duration", G_CALLBACK(on_duration_notify), track);
-	
+						g_signal_connect(track, "notify::duration", G_CALLBACK(on_duration_notify), NULL);
+						track_view=sequencer_track_view_add_backing_track(track, muted,volume);
 					}
 					printf("Ending looking for BackingTrack\n");
 
@@ -234,7 +238,7 @@ if (load_only_backingtrack){
 			else {
 			//EDITING-TRACK
 			if(strncmp(track_type, "EditingTrack", 12) == 0) {
-				gint e_track_type=-1;
+				gint e_track_type=JAMMO_SAMPLE_UNTYPED;
 				gchar* editing_track_type="";
 				//string
 				sub_node = json_object_get_member (sub_object, "editing-track-type");
@@ -243,31 +247,39 @@ if (load_only_backingtrack){
 					printf("editing-track-type: '%s'\n",editing_track_type);
 				}
 				ClutterColor sample_color =  { 0, 0, 0, 255 };
-				if (strncmp(editing_track_type,"Rhythm",6) == 0 ) {
-					e_track_type = RHYTHM_TRACK;
+
+				GEnumClass* enum_class = G_ENUM_CLASS(g_type_class_ref(JAMMO_TYPE_SAMPLE_TYPE));
+				GEnumValue* enum_value = g_enum_get_value_by_nick(enum_class, editing_track_type);
+				g_type_class_unref(enum_class);
+				if (enum_value)
+					e_track_type = enum_value->value;
+
+				track_view=sequencer_track_view_add_with_type(EDITING_TRACK_VIEW,muted,volume,e_track_type);
+
+				if (e_track_type == JAMMO_SAMPLE_RHYTMICAL) {
 					sample_color.red   = 255;
 					sample_color.green = 155;
 					sample_color.blue  = 0;
 				}
-				else if (strncmp(editing_track_type,"Melody",6) == 0 ) {
-					e_track_type = MELODY_TRACK;
+				else if (e_track_type == JAMMO_SAMPLE_MELODICAL) {
 					sample_color.red   = 0;
 					sample_color.green = 0;
 					sample_color.blue  = 155;
 				}
-				else if (strncmp(editing_track_type,"Harmony",7) == 0 ) {
-					e_track_type = HARMONY_TRACK;
+				else if (e_track_type == JAMMO_SAMPLE_HARMONICAL) {
 					sample_color.red   = 200;
 					sample_color.green = 0;
 					sample_color.blue  = 0;
 				}
-				else if (strncmp(editing_track_type,"Effect",6) == 0 ) {
-					e_track_type = EFFECT_TRACK;
+				else if (e_track_type == JAMMO_SAMPLE_EFFECT) {
 					sample_color.red    = 0;
 					sample_color.green  = 155;
 					sample_color.blue   = 0;
 				}
-				track_view=sequencer_track_view_add_with_type(EDITING_TRACK_VIEW,muted,e_track_type);
+				else {
+					sample_color.alpha   = 0;
+				}
+
 				g_object_set(track_view, "sample-color", &sample_color, NULL);
 
 
@@ -299,12 +311,11 @@ if (load_only_backingtrack){
 								slot =  json_node_get_int (sub_node);
 								printf("slot: '%d'\n",slot);
 							}
-							if (track_view==NULL)
-									printf("track_view==NULL\n");
-							ClutterActor* sample_button=NULL;// = theme_give_sample_button_for_this_theme_and_variation_for_this_id(theme_name,variation,loop_id);
+							ClutterActor* sample_button=sequencer_give_sample_button_for_this_id(loop_id);
 							if (sample_button==NULL)
-								printf("sample_button==NULL\n");
-							//jammo_track_view_add_jammo_sample_button(track_view,JAMMO_SAMPLE_BUTTON(sample_button),slot);
+								printf("Loading loop-id '%d' from file: sample_button==NULL, can't add to track.\n",loop_id);
+							else
+								jammo_track_view_add_jammo_sample_button(JAMMO_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(sample_button),slot);
 
 						} //This sample-object is ready
 
@@ -323,7 +334,7 @@ if (load_only_backingtrack){
 						printf("instrument: '%d'\n",instrument);
 					}
 
-				track_view=sequencer_track_view_add_with_type(INSTRUMENT_TRACK_VIEW,muted,instrument);
+				track_view=sequencer_track_view_add_with_type(INSTRUMENT_TRACK_VIEW,muted,volume,instrument);
 
 				//string
 				sub_node = json_object_get_member (sub_object, "note-file");
@@ -346,7 +357,7 @@ if (load_only_backingtrack){
 						printf("instrument: '%d'\n",instrument);
 					}
 
-				track_view=sequencer_track_view_add_with_type(SLIDER_TRACK_VIEW,muted,instrument);
+				track_view=sequencer_track_view_add_with_type(SLIDER_TRACK_VIEW,muted,volume,instrument);
 				//In slider-case: track_view is TangleWidget.
 				track = g_object_get_data(G_OBJECT(track_view), "track");
 
@@ -372,16 +383,8 @@ if (load_only_backingtrack){
 
 			//If we didn't got track, skip this
 			if (track) {
-				//double / float
-				gfloat volume=1.0; //default volume is 100%
-				sub_node = json_object_get_member (sub_object, "volume");
-					if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-						volume = (gfloat) json_node_get_double (sub_node);
-						printf("volume: '%f'\n",volume);
-					}
+				//These are asked earlier
 				jammo_playing_track_set_volume(JAMMO_PLAYING_TRACK(track), volume);
-
-				//This is asked earlier:
 				jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(track), muted);
 			}
 
@@ -397,69 +400,61 @@ g_object_unref(parser);
 
 gboolean sequencer_change_to_loop_view(TangleActor *actor, gpointer data) {
 	printf("changing view to loop \n");
-	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller");
-	clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_CIRC, 400, "scrolling-offset-y", 0.0, NULL);
+	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-view-container");
+	ClutterAction* action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
+	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_CIRC, 400, "offset-y", 0.0, NULL);
 	return TRUE;
 }
 
 gboolean sequencer_change_to_sequencer_view(TangleActor *actor, gpointer data) {
 	printf("changing view to sequencer \n");
-	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller");
-	clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor), CLUTTER_EASE_IN_CIRC, 400, "scrolling-offset-y", 480.0, NULL);
+	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-view-container");
+	ClutterAction* action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
+	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_CIRC, 400, "offset-y", 480.0, NULL);
 	return TRUE;
 }
 
 gboolean sequencer_change_to_bottom_view (TangleActor *actor, gpointer data) {
 	printf("changing view to bottom \n");
-	ClutterActor* scrolling_actor = jammo_get_actor_by_id("fullsequencer-scroller");
-	clutter_actor_animate(CLUTTER_ACTOR(scrolling_actor),   CLUTTER_EASE_IN_CIRC, 400, "scrolling-offset-y", 960.0, NULL);
+	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-view-container");
+	ClutterAction* action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
+	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_CIRC, 400, "offset-y", 960.0, NULL);
 	return TRUE;
 }
 
 
 
-static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer backing_track) {
+static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer none) {
 
-	JammoSample* sample;
-	sample = JAMMO_SAMPLE(object);
+	//Now we know duration of backing-track, which is also duration of Sequencer
+	//so we can tune width of area. (needed for cursor e.g.)
+	sequencer_track_view_tune_width();
 
-	// The duration of backing track is used to set fixed duration for other tracks
-	guint64 duration;
-	duration = jammo_sample_get_duration(sample);
-	g_print("Duration: %" G_GUINT64_FORMAT "\n", duration);
-
-	gint tempo_factory = 4;
-	//We want operate whole time with guint64.
-	guint64 temp=60*tempo_factory;
-	guint64 one_second = 1000000000L;
-	guint64 big = temp * one_second;
-	guint64 duration_of_one_slot = big / jammo_sequencer_get_tempo(static_sequencer);
-
-	gint number_of_slots = duration/duration_of_one_slot;
-	printf("*number_of_slots in backing_track: %d\n",number_of_slots);
-	gfloat slot_width = 40.0;
-	gfloat height = 50.0;
-	//sequencer_track_view uses internally this just created area.
-	sequencer_track_view_create_area_for_tracks(static_sequencer,number_of_slots, duration, slot_width,height);
-
-
-	ClutterActor* track_view = NULL;
-	track_view=sequencer_track_view_add_backing_track(backing_track, jammo_playing_track_get_muted(backing_track));
 
 	//continue loading
 	load_state_from_file(inputFilename,FALSE);
 
 	// Do not call this function ever again!
-	g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_duration_notify), static_sequencer);
+	g_signal_handlers_disconnect_by_func(object, G_CALLBACK(on_duration_notify), NULL);
 }
 
-JammoMetronomeTrack* static_metronome_track;
+//We want load saved composition only first time
+static gboolean first_time = TRUE;
+
+/* JSON callback when sequencer-view is showed*/
+void start_sequencer_full_sequencer (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+	if (first_time)
+		start_sequencer("seq.json"); //This is default
+	first_time=FALSE;
+}
 
 /*
 This actor is visible when starting jammo_get_actor_by_id("fullsequencer-view");
 */
 void start_sequencer(gpointer filename)
 {
+	printf("Starting sequencer GUI\n");
+
 	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	static_metronome_track = jammo_metronome_track_new();
 	jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(static_metronome_track));
@@ -468,7 +463,6 @@ void start_sequencer(gpointer filename)
 	jammo_metronome_track_set_accent(static_metronome_track,FALSE);
 	jammo_playing_track_set_muted(JAMMO_PLAYING_TRACK(static_metronome_track), TRUE);
 
-	printf("Starting sequencer GUI\n");
 	//inputFilename is global! (from sequencer.h)
 	if (filename == NULL)
 		inputFilename = NULL;
