@@ -176,7 +176,13 @@ static void create_directories(void) {
 		printf("Error, can't call '%s'\n", cmd);
 	}
 	g_free(cmd);
-	
+
+	cmd= g_strdup_printf("mkdir -p %s/7-12",COMPOSITIONS_DIRECTORY); //Compositions for 7-12 game
+	if (system(cmd)) {
+		printf("Error, can't call '%s'\n", cmd);
+	}
+	g_free(cmd);
+
 	cmd = g_strdup_printf("mkdir -p %s",SINGINGS_DIRECTORY);
 	if (system(cmd)) {
 		printf("Error, can't call '%s'\n", cmd);
@@ -330,34 +336,27 @@ int main(int argc, char** argv) {
 
 	else if (!strcmp(application_name,"jammo7_12")) { //start jammo 7-12 years
 		printf("Starting 7-12 years game\n");
-		//start_gamesmenu(); //this only starts mockup menu
-		//start_sequencer(NULL); //this starts empty sequencer
-		start_sequencer("/opt/jammo/seq.json");
 	}
 
+	//These are only debug shortcuts:
 	//Started with name jammo: check commandline parameters
 	else {
-		if (argc==2 && strcmp(argv[1],"editor")==0) {
-			midi_editor_start_with_filename(NULL);
-		}
-		else if (argc==3 && strcmp(argv[1],"editor")==0) {
-			midi_editor_start_with_filename(argv[2]);
-		}
-		else if (argc==2 && strcmp(argv[1],"sequencer")==0) {
-			start_sequencer(NULL);
-		}
-		else if (argc==3 && strcmp(argv[1],"sequencer")==0) {
-			start_sequencer(argv[2]);
-		}
-		else if (argc==2 && strcmp(argv[1],"startmenu")==0) {
-			start_startmenu();
-		}
-		else if (argc==2 && strcmp(argv[1],"gamesmenu")==0) {
-			start_gamesmenu();
-		}
-		else if (argc==2 && strcmp(argv[1],"communitymenu")==0) {
-			start_communitymenu();
+// 		if (argc==2 && strcmp(argv[1],"editor")==0) {
+// 			midi_editor_start_with_filename(NULL);
+// 		}
+// 		else if (argc==3 && strcmp(argv[1],"editor")==0) {
+// 			midi_editor_start_with_filename(argv[2]);
+// 		}
+		if (argc==2 && strcmp(argv[1],"sequencer")==0) {
+			clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));
+			clutter_actor_hide(jammo_get_actor_by_id("startmenu-view"));
 		}
+// 		else if (argc==2 && strcmp(argv[1],"gamesmenu")==0) {
+// 			start_gamesmenu();
+// 		}
+// 		else if (argc==2 && strcmp(argv[1],"communitymenu")==0) {
+// 			start_communitymenu();
+// 		}
 		else { //Do not use this with commandline parameters
 			g_timeout_add(10, start_3_6_game,NULL);
 			g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
@@ -365,7 +364,7 @@ int main(int argc, char** argv) {
 	}
 
 	g_free(application_path);
-
+printf("start clutter-main\n");
 	clutter_main();
 
 	g_object_unref(script);
