@@ -161,12 +161,12 @@ static void on_duration_notify(GObject* object, GParamSpec* pspec, gpointer user
 	clutter_container_add(CLUTTER_CONTAINER(stage), jammo_get_actor_by_id("fullsequencer-track-area"), NULL);
 
 	//There are also another loop_track types, but it onl affects for label-image
-	sequencer_track_view_add_with_type("DRUM_TRACK_VIEW");
-	sequencer_track_view_add_with_type("DRUM_TRACK_VIEW");
-	sequencer_track_view_add_with_type("DRUM_TRACK_VIEW");
-	sequencer_track_view_add_with_type("DRUM_TRACK_VIEW");
-	sequencer_track_view_add_with_type("DRUM_TRACK_VIEW");
-	sequencer_track_view_add_with_type("DRUM_TRACK_VIEW");
+	sequencer_track_view_add_with_type(DRUM_TRACK_VIEW,FALSE,-1);
+	sequencer_track_view_add_with_type(DRUM_TRACK_VIEW,FALSE,-1);
+	sequencer_track_view_add_with_type(DRUM_TRACK_VIEW,FALSE,-1);
+	sequencer_track_view_add_with_type(DRUM_TRACK_VIEW,FALSE,-1);
+	sequencer_track_view_add_with_type(DRUM_TRACK_VIEW,FALSE,-1);
+	sequencer_track_view_add_with_type(DRUM_TRACK_VIEW,FALSE,-1);
 
 	clutter_actor_show_all (stage);
 
